// Shows the number of datablocks in your mod, it's capacity (in limitation to T2's internal limit)
function datablockInfo() {
     %blocks = DataBlockGroup.getCount();
     %effects = 0;

     for(%i = 0; %i < %blocks; %i++) {
        if(DataBlockGroup.getObject(%i).getClassName() $= "EffectProfile") {
           %effects++;
           echo(""@%i@". "@DataBlockGroup.getObject(%i).getName()@"");
        }
     }

     echo("Number of Datablocks:");
     error(%blocks);
     echo("Current Datablock Capacity:");
     error(mCeil((%blocks / 2048)*100)@"%");
     echo("Number of EffectProfile datablocks:");
     error(%effects);
     echo("Percentage of EffectProfile usage on datablock pool:");
     error(mCeil((%effects / 2048)*100)@"%");

     if(%effects)
          echo("You have some EffectProfiles remaining. Eliminate them to free up unused datablock space. EffectProfiles are unused Force Feedback datablocks, often attached to sounds. These can be safely removed from all SoundProfile datablocks and removed.");
}

// This function allows you to reload all modified
function reload(%script)
{
    exec(%script);

    %count = ClientGroup.getCount();

    for(%i = 0; %i < %count; %i++)
    {
        %cl = ClientGroup.getObject(%i);

        // Prevent sending new datablocks to connecting players, they'll get them all anyway
        if(!%cl.isAIControlled() && %cl.currentPhase > 2)
            %cl.transmitDataBlocks(0);
    }
}

// Required for reload() to work properly - watch for this in console
function GameConnection::dataBlocksDone( %client, %missionSequence )
{
   echo("Client "@%client@" ("@getTaggedString(%client.name)@") finished datablock load.");

   if(%missionSequence != $missionSequence)
      return;

   if(%client.currentPhase != 1)
      return;
   %client.currentPhase = 2;

   // only want to set this once... (targets will not be updated/sent until a
   // client has this flag set)
   if(!%client.getReceivedDataBlocks())
   {
      %client.setReceivedDataBlocks(true);
      sendTargetsToClient(%client);
   }

   commandToClient(%client, 'MissionStartPhase2', $missionSequence);
}

// Allows you to retrieve all information about a clientID, best used for verbose logging on connection
function getFullClientInfo(%client)
{
   echo("==================================== Client Info");
   echo("Assigned Client ID: " @ %client @ " IP Address: " @ %client.getAddress());
   echo("Connection Name: "@getTaggedString(%client.name)@" Real Name: "@%client.realname@" GUID: "@%client.guid@"\nSkin: "@getTaggedString(%client.skin)@" Voice: "@getTaggedString(%client.voiceTag)@" Pitch: "@%client.voicePitch);
   echo("Auth Info: \n"@%client.getAuthInfo());
   echo("==========================================================");
}

function calcSpreadVector(%vector, %val)
{
   %x = (getRandom() - 0.5) * 2 * $PI * (%val / 1000);
   %y = (getRandom() - 0.5) * 2 * $PI * (%val / 1000);
   %z = (getRandom() - 0.5) * 2 * $PI * (%val / 1000);
   %mat = MatrixCreateFromEuler(%x SPC %y SPC %z);

   return MatrixMulVector(%mat, %vector);
}

// Simple boolean operations that tell whether an object is something
function SimObject::isPlayer(%obj)
{
     isPlayer(%obj);
}

function SimObject::isVehicle(%obj)
{
     isVehicle(%obj);
}

function SimObject::isTurret(%obj)
{
     isTurret(%obj);
}

// Is this object a Player?
function isPlayer(%obj)
{
     return %obj.getType() & $TypeMasks::PlayerObjectType;
}

// Is this object a Vehicle?
function isVehicle(%obj)
{
     return %obj.getType() & $TypeMasks::VehicleObjectType;
}

// Is this object a Turret?
function isTurret(%obj)
{
     return %obj.getType() & $TypeMasks::TurretObjectType;
}

//Lol, Random Name for Player COunt Loop
function PlayerCountFixLoop() {
   %bots = 0;
   %c = ClientGroup.getCount();
   $HostGamePlayerCount = %c;
   for(%i = 0; %i < %c; %i++) {
      %cl = ClientGroup.getObject(%i);
      if(%cl.isAiControlled()) {
         %bots++;
      }
   }
   $HostGameBotCount = %bots;
   schedule(10000,0,"PlayerCountFixLoop");
}

//DoL's Mission Area Function
function RMPG() {
   %X = getWord(MissionArea.getArea(), 0);
   %Y = getWord(MissionArea.getArea(), 1);
   %W = getWord(MissionArea.getArea(), 2);
   %H = getWord(MissionArea.getArea(), 3);

   %OppX = ((%X) + (%W));
   %OppY = ((%Y) + (%H));
   %Position = getRandom(%X, %OppX) SPC getRandom(%Y, %OppY) SPC 0;

   %Z = getTerrainHeight(%position);
   %PositionF = getWord(%Position, 0) SPC getWord(%Position, 1) SPC %Z;

   return %PositionF;
}

function isAlive(%pl) {
   if(isObject(%pl)) {
      if(%pl.getState() $= "dead") {
         return false;
      }
      else {
         return true;
      }
   }
   else {
      return false;
   }
}
