// DisplayName = Defcon

//--- GAME RULES BEGIN ---
// Build your base
// Collect resources
// Destroy enemies
//--- GAME RULES END ---

// spam fix
function DefconGame::AIInit(%game) {
	//call the default AIInit() function
	AIInit();
}

function DefconGame::setUpTeams(%game)
{
   %group = nameToID("MissionGroup/Teams");
   if(%group == -1)
      return;

   // create a team0 if it does not exist
   %team = nameToID("MissionGroup/Teams/team0");
   if(%team == -1)
   {
      %team = new SimGroup("team0");
      %group.add(%team);
   }

   // 'team0' is not counted as a team here
   %game.numTeams = 0;
   while(%team != -1)
   {
      // create drop set and add all spawnsphere objects into it
      %dropSet = new SimSet("TeamDrops" @ %game.numTeams);
      MissionCleanup.add(%dropSet);

      %spawns = nameToID("MissionGroup/Teams/team" @ %game.numTeams @ "/SpawnSpheres");
      if(%spawns != -1)
      {
         %count = %spawns.getCount();
         for(%i = 0; %i < %count; %i++)
            %dropSet.add(%spawns.getObject(%i));
      }

      // set the 'team' field for all the objects in this team
      %team.setTeam(0);

      clearVehicleCount(%team+1);
      // get next group
      %team = nameToID("MissionGroup/Teams/team" @ %game.numTeams + 1);
      if (%team != -1)
         %game.numTeams++;
   }

   // set the number of sensor groups (including team0) that are processed
   setSensorGroupCount(%game.numTeams + 1);
   %game.numTeams = 1;

   setSensorGroupAlwaysVisMask(0, 0xffffffff);
   // allow teams 1->31 to listen to each other (team 0 can only listen to self)
   for(%i = 1; %i < 32; %i++) {
      setSensorGroupListenMask(%i, 0xfffffffe);
      setSensorGroupAlwaysVisMask(%i, 0xffffffff); //all teams may see eachother
   }
}

//MORE TEAMS STUFF
function DefconGame::pickPlayerSpawn(%game, %client, %respawn) {
   // all spawns come from team 1
   %group = nameToID("DefconArmy"@%client@"");
   if(%group != -1) {
      %pos = vectorAdd(%client.CP.getPosition(), "0 0 10");
   }
   else {
      %pos = "0 0 110"; // you will be moved soon!
   }
   return %pos;
}

function DefconGame::clientJoinTeam( %game, %client, %team, %respawn ) {
   %game.assignClientTeam( %client );

   // Spawn the player:
   %game.spawnPlayer( %client, %respawn );
}

function DefconGame::assignClientTeam(%game, %client) {
   for(%i = 1; %i < 32; %i++)
      $DefconTeamArray[%i] = false;

   %maxSensorGroup = 0;
   %count = ClientGroup.getCount();
   for(%i = 0; %i < %count; %i++)
   {
      %cl = ClientGroup.getObject(%i);
      if(%cl != %client)
      {
         $DefconTeamArray[%cl.team] = true;
         if (%cl.team > %maxSensorGroup)
            %maxSensorGroup = %cl.team;
      }
   }

   //now loop through the team array, looking for an empty team
   for(%i = 1; %i < 32; %i++)
   {
      if (! $DefconTeamArray[%i])
      {
         %client.team = %i;
         if (%client.team > %maxSensorGroup)
            %maxSensorGroup = %client.team;
         break;
      }
   }

   // set player's skin pref here
   setTargetSkin(%client.target, %client.skin);

   // Let everybody know you are no longer an observer:
   messageAll( 'MsgClientJoinTeam', '\c1%1 has joined his army, and declared war!.', %client.name, "", %client, 1 );
   updateCanListenState( %client );

   //now set the max number of sensor groups...
   setSensorGroupCount(%maxSensorGroup + 1);
   %game.schedule(1000, "FindInitialPoint", %client);
}
//END

function DefconGame::allowsProtectedStatics(%game) {
	return true;
}

function DefconGame::clientMissionDropReady(%game, %client) {
	messageClient(%client, 'MsgClientReady',"", %game.class);
	messageClient(%client, 'MsgMissionDropInfo', '\c0You are in mission %1 (%2).', $MissionDisplayName, $MissionTypeDisplayName, $ServerName );
	DefaultGame::clientMissionDropReady(%game, %client);
 
    //
    InitialBalance(%client);
    //
}

function DefconGame::FindInitialPoint(%game, %client) {
   %pt = RMPG();
   //player has a base (probably went Obs)
   %group = nameToID("DefconArmy"@%client@"");
   echo("DEFCON: Setting up "@%client@"");
   if(%group != -1) {
      %client.team = %client.CP.team;
      setTargetSensorGroup(%client.target, %client.team);
   }
   //new player or destroyed player, let's set him up
   else {
      %group = new SimGroup("DefconArmy"@%client@"");
      %client.CP = new StaticShape() {
         datablock = "CommandPost";
         position = %pt;
         team = %client.team;
      };
      %client.CP.team = %client.team;
      %group.add(%client.CP);
      %client.player.setPosition(VectorAdd(%pt, "0 0 10"));
      
      %client.CP.DefconLevel = 6;
      
      //team stuff
  	  if (%client.CP.getTarget() != -1)
         setTargetSensorGroup(%client.CP.getTarget(), %client.team);
         
      %client.CP.PAD = new StaticShape() {
         datablock = "ControlStation";
         position = vectorAdd(%pt, "4 4 0");
         team = %client.team;
      };
      %client.CP.PAD.team = %client.team;
      %group.add(%client.CP.PAD);
      %client.CP.PAD.hudToPush = "CommandPost";
      %client.CP.PAD.main = %client.CP;

      //team stuff
  	  if (%client.CP.PAD.getTarget() != -1)
         setTargetSensorGroup(%client.CP.PAD.getTarget(), %client.team);
   }
}

function DefconGame::onAIRespawn(%game, %client)
{
   //add the default task
	if (! %client.defaultTasksAdded)
	{
		%client.defaultTasksAdded = true;
	   %client.addTask(AIPickupItemTask);
	   %client.addTask(AIUseInventoryTask);
	   %client.addTask(AITauntCorpseTask);
		%client.addTask(AIEngageTurretTask);
		%client.addTask(AIDetectMineTask);
		%client.addTask(AIBountyPatrolTask);
		%client.bountyTask = %client.addTask(AIBountyEngageTask);
	}

   //set the inv flag
   %client.spawnUseInv = true;
}

function DefconGame::updateKillScores(%game, %clVictim, %clKiller, %damageType, %implement) {
	if (%game.testKill(%clVictim, %clKiller)) { //verify victim was an enemy
		%game.awardScoreKill(%clKiller);
		%game.awardScoreDeath(%clVictim);
	}
	else if (%game.testSuicide(%clVictim, %clKiller, %damageType))  //otherwise test for suicide
		%game.awardScoreSuicide(%clVictim);
}

function DefconGame::timeLimitReached(%game) {
	logEcho("game over (timelimit)");
	%game.gameOver();
	cycleMissions();
}

function DefconGame::scoreLimitReached(%game) {
	logEcho("game over (scorelimit)");
	%game.gameOver();
	cycleMissions();
}

function DefconGame::startMatch(%game) {
   DefaultGame::startMatch(%game);
   placeRandomResourceZones();
}

function DefconGame::gameOver(%game) {
	//call the default
    CleanGroups();
	DefaultGame::gameOver(%game);

	//send the winner message
	%winner = "";
	if ($teamScore[1] > $teamScore[2])
		%winner = %game.getTeamName(1);
	else if ($teamScore[2] > $teamScore[1])
		%winner = %game.getTeamName(2);

	if (%winner $= 'Storm')
		messageAll('MsgGameOver', "Match has ended.~wvoice/announcer/ann.stowins.wav" );
	else if (%winner $= 'Inferno')
		messageAll('MsgGameOver', "Match has ended.~wvoice/announcer/ann.infwins.wav" );
	else if (%winner $= 'Starwolf')
		messageAll('MsgGameOver', "Match has ended.~wvoice/announcer/ann.swwin.wav" );
	else if (%winner $= 'Blood Eagle')
		messageAll('MsgGameOver', "Match has ended.~wvoice/announcer/ann.bewin.wav" );
	else if (%winner $= 'Diamond Sword')
		messageAll('MsgGameOver', "Match has ended.~wvoice/announcer/ann.dswin.wav" );
	else if (%winner $= 'Phoenix')
		messageAll('MsgGameOver', "Match has ended.~wvoice/announcer/ann.pxwin.wav" );
	else
		messageAll('MsgGameOver', "Match has ended.~wvoice/announcer/ann.gameover.wav" );

	messageAll('MsgClearObjHud', "");
	for(%i = 0; %i < ClientGroup.getCount(); %i ++) {
		%client = ClientGroup.getObject(%i);
		%game.resetScore(%client);
	}
	for(%j = 1; %j <= %game.numTeams; %j++)
		$TeamScore[%j] = 0;
}

function DefconGame::vehicleDestroyed(%game, %vehicle, %destroyer) {
}

